<?php function shb_stripe_payment_shortcode( $atts, $content = null ) {
	
	extract( shortcode_atts( array(
		'amount' => '',
		'id' => ''
	), $atts ) );
	
	ob_start();
	
	if(!empty(get_option('shb_price_decimal_separator'))) {
		$price_decimal_separator = get_option('shb_price_decimal_separator');
	} else {
		$price_decimal_separator = '.';
	}
	
	if(!empty(get_option('shb_price_thousand_separator'))) {
		$price_thousand_separator = get_option('shb_price_thousand_separator');
	} else {
		$price_thousand_separator = ',';
	}
	
	$amount_cents = $amount;
	$amount_original = array($price_decimal_separator,$price_thousand_separator);
	$amount_replace = array('','');
	$amount = str_replace($amount_original,$amount_replace,$amount);
	
	// Stripe library
	require 'stripe/init.php';

	$options = array(
		'testmode'   => get_option('shb_stripe_testmode'),
		'private_live_key' => get_option('shb_stripe_api_sk_live'),
		'public_live_key'  => get_option('shb_stripe_api_pk_live'),
		'private_test_key' => get_option('shb_stripe_api_sk_test'),
		'public_test_key'  => get_option('shb_stripe_api_pk_test'),
		'currency'  => get_option('shb_stripe_currency'),
		'amount'  => $amount,
		'id'  => $id
	);
	
	if ($options['testmode'] == 'on') {
		\Stripe\Stripe::setApiKey($options['private_test_key']);
		$pubkey = $options['public_test_key'];
	} else {
		\Stripe\Stripe::setApiKey($options['private_live_key']);
		$pubkey = $options['public_live_key'];
	}

	if(isset($_POST['stripeToken'])) {
		
		$description = 'Booking #' . $options['id'];
		
		$token_id = $_POST['stripeToken'];
	
		$intent = \Stripe\PaymentIntent::create([
			'payment_method_data' => [
				'type' => 'card',
				'card' => ['token' => $token_id],
			],
			'amount' => $amount,
			'currency' => $options['currency'],
			'confirmation_method' => 'manual',
			'confirm' => true,
			'description' => $description
		]);
		
		if($intent->status == 'succeeded') {
			
			// Update payment amount
			$data = array(
				'booking_id' => $id,
				'payment_method' => __('Stripe','sohohotel_booking'),
				'amount_paid' => $amount_cents
			);
			shb_update_booking_payment($data);
			
			// Send booking emails
			shb_send_confirmation_email($id,'customer_payment_confirmation');
			shb_send_confirmation_email($id,'admin_payment_confirmation');
			
		} else {
	
			_e('Payment failed','sohohotel_booking');
			
		}
		
	} else { ?>
			
		<form action="" method="post" id="payment-form" class="shb-stripe-payment-form">
			<input type="hidden" name="shb-stripe-amount" value="<?php echo $amount_cents; ?>" />
			<input type="hidden" name="shb-stripe-id" value="<?php echo $id; ?>" />
			<input type="text" id="card_name" class="field" placeholder="Cardholder name" />
			<div id="card-element"></div>
			<div id="card-errors" role="alert"></div>
			<input type="submit" class="submit" value="<?php _e('Submit Payment','sohohotel_booking'); ?>">
		</form>
	
		<script type="text/javascript">
			
			var stripe = Stripe('<?php echo $pubkey; ?>');
			var elements = stripe.elements();
			var card = elements.create(
				'card',
				{
					hidePostalCode: true
				}
			);
			card.mount('#card-element');
	
			card.addEventListener('change', function(event) {
				var displayError = document.getElementById('card-errors');
				if (event.error) {
					displayError.textContent = event.error.message;
				} else {
					displayError.textContent = '';
				}
			});
	
			function stripeTokenHandler(token) {
				var form = document.getElementById('payment-form');
				var hiddenInput = document.createElement('input');
				hiddenInput.setAttribute('type', 'hidden');
				hiddenInput.setAttribute('name', 'stripeToken');
				hiddenInput.setAttribute('value', token.id);
				form.appendChild(hiddenInput);
				form.submit();
			}
	
			function createToken() {
		
				var card_name = document.getElementById('card_name').value;
		
				stripe.createToken(card, {name: card_name}).then(function(result) {
			
					if (result.error) {
						var errorElement = document.getElementById('card-errors');
						errorElement.textContent = result.error.message;
					} else {
						stripeTokenHandler(result.token);
					}
				});
			};
	
			var form = document.getElementById('payment-form');
			form.addEventListener('submit', function(e) {
				e.preventDefault();
				createToken();
			});
			
		</script>
	
	<?php } 
	
	return ob_get_clean();

}

add_shortcode( 'shb_stripe_payment', 'shb_stripe_payment_shortcode' );