<?php



/* ----------------------------------------------------------------------------

   Get all IDs for a specific post type

---------------------------------------------------------------------------- */
function shb_get_all_ids($post_type) {
	
	$ids = get_posts(array(
	    'fields'          => 'ids',
	    'posts_per_page'  => -1,
		'post_type' => $post_type,
		'orderby' => 'date',
		'order' => 'ASC'
	));
	
	$ids = shb_get_translated_wpml_ids($ids,$post_type);
	
	return $ids;
	
}



/* ----------------------------------------------------------------------------

   Get translated WPML IDs

---------------------------------------------------------------------------- */
function shb_get_translated_wpml_ids($ids,$posttype) {
	
	// If WPML is running get translated IDs
	if (class_exists('SitePress')) {

		$sh_wpml_translated_ids = array();
		foreach($ids as $key => $val) {	
			
			if(apply_filters( 'wpml_object_id', $val, $posttype ) != '') {
				$sh_wpml_translated_ids[] = apply_filters( 'wpml_object_id', $val, $posttype );
			}
			
		}
		return array_unique($sh_wpml_translated_ids);

	// If WPML is not running just return the input IDs and do nothing
	} else {
		return $ids;
	}
	
}



/* ----------------------------------------------------------------------------

   Get original WPML ID (string)

---------------------------------------------------------------------------- */
function shb_get_original_wpml_id($id,$posttype) {
	
	// If WPML is running get translated IDs
	if (class_exists('SitePress')) {
		
		global $sitepress;
		return apply_filters( 'wpml_object_id', $id, $posttype, true, $sitepress->get_default_language() );

	// If WPML is not running just return the input IDs and do nothing
	} else {
		return $id;
	}
	
}



/* ----------------------------------------------------------------------------

   Get translated WPML IDs for accommodation

---------------------------------------------------------------------------- */
function shb_get_translated_wpml_ids_accommodation($ids) {
	
	$posttype = 'shb_accommodation';
	
	// If WPML is running get translated IDs
	if (class_exists('SitePress')) {

		$sh_wpml_translated_ids = array();
		foreach($ids as $key => $val) {	
			
			if(apply_filters( 'wpml_object_id', $key, $posttype ) != '') {
				$sh_wpml_translated_ids[apply_filters( 'wpml_object_id', $key, $posttype )] = $val;
			}
			
		}
		return $sh_wpml_translated_ids;

	// If WPML is not running just return the input IDs and do nothing
	} else {
		return $ids;
	}
	
}





/* ----------------------------------------------------------------------------

   Get all IDs for a specific post type and category

---------------------------------------------------------------------------- */
function shb_get_all_ids_category($post_type,$hotel_category) {
	
	if(!empty($hotel_category)) {
		$ids = get_posts(array(
		    'fields'          => 'ids',
			'tax_query' => array(
				array(
					'taxonomy' => 'accommodation-categories',
					'field'    => 'slug',
					'terms'    => $hotel_category,
				),
			),
		    'posts_per_page'  => -1,
			'post_type' => $post_type,
			'orderby' => 'date',
			'order' => 'ASC'
		));
	} else {
		$ids = get_posts(array(
		    'fields'          => 'ids',
		    'posts_per_page'  => -1,
			'post_type' => $post_type,
			'orderby' => 'date',
			'order' => 'ASC'
		));
	}
	
	return $ids;
	
}



/* ----------------------------------------------------------------------------

   Get price with currency symbol

---------------------------------------------------------------------------- */
function shb_get_price($price) {
	
	/*$tax_ids = shb_get_all_ids('shb_tax');
	foreach($tax_ids as $val) {
		$tax_rate[] = get_post_meta($val,'shb_tax_rate',TRUE);
	}
	$tax_total = array_sum($tax_rate);
	$price = ( $price + shb_calc_tax_percentage($price,$tax_total) );*/
	
	if(!empty(get_option('shb_currency_symbol'))) {
		$currency_symbol = get_option('shb_currency_symbol');
	} else {
		$currency_symbol = '$';
	}
	
	if(!empty(get_option('shb_currency_symbol_position'))) {
		$currency_symbol_position = get_option('shb_currency_symbol_position');
	} else {
		$currency_symbol_position = 'before';
	}
	
	if(!empty(get_option('shb_price_decimal_places'))) {
		
		if(get_option('shb_price_decimal_places') == 'zero') {
			$price_decimal_places = 0;
		} elseif(get_option('shb_price_decimal_places') == 'one') {
			$price_decimal_places = 1;
		} elseif(get_option('shb_price_decimal_places') == 'two') {
			$price_decimal_places = 2;
		} elseif(get_option('shb_price_decimal_places') == 'three') {
			$price_decimal_places = 3;
		} elseif(get_option('shb_price_decimal_places') == 'four') {
			$price_decimal_places = 4;
		} else {
			$price_decimal_places = 0;
		}
		
	} else {
		$price_decimal_places = 0;
	}
	
	if(!empty(get_option('shb_price_decimal_separator'))) {
		$price_decimal_separator = get_option('shb_price_decimal_separator');
	} else {
		$price_decimal_separator = '.';
	}
	
	if(!empty(get_option('shb_price_thousand_separator'))) {
		$price_thousand_separator = get_option('shb_price_thousand_separator');
	} else {
		$price_thousand_separator = ',';
	}
	
	$price = number_format((float)$price, $price_decimal_places, $price_decimal_separator, $price_thousand_separator);
	
	if($currency_symbol_position == 'before') {
		$get_price = $currency_symbol . $price;
	} else {
		$get_price = $price . $currency_symbol;
	}
	
	return $get_price;
	
}



/* ----------------------------------------------------------------------------

   Get price without currency symbol

---------------------------------------------------------------------------- */
function shb_get_price_no_currency_symbol($price) {
	
	if(!empty(get_option('shb_price_decimal_places'))) {
		
		if(get_option('shb_price_decimal_places') == 'zero') {
			$price_decimal_places = 0;
		} elseif(get_option('shb_price_decimal_places') == 'one') {
			$price_decimal_places = 1;
		} elseif(get_option('shb_price_decimal_places') == 'two') {
			$price_decimal_places = 2;
		} elseif(get_option('shb_price_decimal_places') == 'three') {
			$price_decimal_places = 3;
		} elseif(get_option('shb_price_decimal_places') == 'four') {
			$price_decimal_places = 4;
		} else {
			$price_decimal_places = 0;
		}
		
	} else {
		$price_decimal_places = 0;
	}
	
	if(!empty(get_option('shb_price_decimal_separator'))) {
		$price_decimal_separator = get_option('shb_price_decimal_separator');
	} else {
		$price_decimal_separator = '.';
	}
	
	if(!empty(get_option('shb_price_thousand_separator'))) {
		$price_thousand_separator = get_option('shb_price_thousand_separator');
	} else {
		$price_thousand_separator = ',';
	}
	
	$price = number_format((float)$price, $price_decimal_places, $price_decimal_separator, $price_thousand_separator);
	
	$get_price = $price;
	
	return $get_price;
	
}



/* ----------------------------------------------------------------------------

   Get price with currency symbol

---------------------------------------------------------------------------- */
function shb_get_date($date) {
	
	$date = explode('-',$date);
	$date_format = get_option('shb_date_format');
	
	if($date_format == 'DD/MM/YYYY') {
		$formatted_date = $date[2] . '/' . $date[1] . '/' . $date[0];
	} 
	
	elseif($date_format == 'MM/DD/YYYY') {
		$formatted_date = $date[1] . '/' . $date[2] . '/' . $date[0];
	}
	
	elseif($date_format == 'YYYY/MM/DD') {
		$formatted_date = $date[0] . '/' . $date[1] . '/' . $date[2];
	}
	
	elseif($date_format == 'DD.MM.YYYY') {
		$formatted_date = $date[2] . '.' . $date[1] . '.' . $date[0];
	}
	
	elseif($date_format == 'MM.DD.YYYY') {
		$formatted_date = $date[1] . '.' . $date[2] . '.' . $date[0];
	}
	
	elseif($date_format == 'YYYY.MM.DD') {
		$formatted_date = $date[0] . '.' . $date[1] . '.' . $date[2];
	}
	
	else {
		$formatted_date = $date[2] . '/' . $date[1] . '/' . $date[0];
	}
	
	return $formatted_date;
	
}



/* ----------------------------------------------------------------------------

   Get currency symbol

---------------------------------------------------------------------------- */
function shb_get_currency_symbol() {

	$currency_symbol = '$';
	
	return $currency_symbol;
	
}



/* ----------------------------------------------------------------------------

   Get select season/room for admin columns

---------------------------------------------------------------------------- */
function shb_get_column_selected_fields($meta_data,$post_type,$post_type_ids,$permalink) {
	
	$column = '';
	
	if ( !empty($meta_data['shb_' . $post_type . '_default'][0]) ) {
		$column .= '<span class="shb-' . $post_type . '-column">';
		$column .= __('Default','sohohotel_booking') . '<span>, </span>';
		$column .= '</span>';
	}
	
	foreach ($post_type_ids as $val) {
		if(!empty($meta_data['shb_' . $post_type . '_' . $val][0])) {
			
			$column .= '<span class="shb-' . $post_type . '-column">';
			
			if(get_the_title($meta_data['shb_' . $post_type . '_' . $val][0]) == '') {
				$title = '(' . __('no title','sohohotel_booking') . ')';
			} else {
				$title = get_the_title($meta_data['shb_' . $post_type . '_' . $val][0]);
			}
			
			if($permalink == true) {
				$column .= '<a target="_blank" href="' . get_the_permalink($meta_data['shb_' . $post_type . '_' . $val][0]) . '">' . $title . '</a><span>, </span>';
			} else {
				$column .= $title . '<span>, </span>';
			}
			
			$column .= '</span>';
		
		}
	}
	
	if ($column == '') {
		return '-';
	} else {
		return $column;
	}
	
}



/* ----------------------------------------------------------------------------

   Get display text

---------------------------------------------------------------------------- */
function shb_get_display_text($data) {
	
	$text = array(
		'fee_type1_fixed_amount' => __('Fixed Fee','sohohotel_booking'),
		'fee_type1_per_room' => __('Per Room','sohohotel_booking'),
		'fee_type1_per_person' => __('Per Person','sohohotel_booking'),
		'fee_type2_night' => __('Per Night','sohohotel_booking'),
		'fee_type2_booking' => __('Per Booking','sohohotel_booking'),
		'discount_type_percentage' => __('Percentage','sohohotel_booking'),
		'discount_type_flat_rate' => __('Flat Rate','sohohotel_booking'),
		'shb_pending' => __('Pending','sohohotel_booking'),
		'shb_confirmed' => __('Confirmed','sohohotel_booking'),
		'shb_cancelled' => __('Cancelled','sohohotel_booking'),
		'shb_ical' => __('iCal','sohohotel_booking'),
		'percentage' => __('Percentage','sohohotel_booking'),
		'exact' => __('Exact Price','sohohotel_booking'),
		'private' => __('Private','sohohotel_booking'),
		'dorm' => __('Dorm','sohohotel_booking'),
		'yes' => __('Yes','sohohotel_booking'),
		'no' => __('No','sohohotel_booking'),
		'duration' => __('Duration','sohohotel_booking'),
		'early' => __('Early','sohohotel_booking'),
		'late' => __('Late','sohohotel_booking')
	);
	
	foreach ($text as $key => $val) {
		
		if($key == $data) {
			return $val;
		}
		
	}

}



/* ----------------------------------------------------------------------------

   Get available room IDs

---------------------------------------------------------------------------- */
function shb_get_available_room_ids($checkin,$checkout,$hotel_category) {
	
	$checkout = date( 'Y-m-d', strtotime( $checkout . ' -1 day' ) );
	
	$available_room_ids = array();
	
	$room_ids = shb_get_all_ids_category('shb_accommodation',$hotel_category);

	// Get booking IDs which overlap with dates and are confirmed status
	$booking_ids_query = get_posts(array(
	    'fields'          => 'ids',
	    'posts_per_page'  => -1,
		'post_type' => 'shb_booking',
		'post_status' => array('shb_confirmed','shb_ical')
	));
	
	$booking_ids = array();
	
	foreach ($booking_ids_query as $booking_id) {
		
		$booking_post_meta = get_post_meta($booking_id);
		
		$checkout2 = date( 'Y-m-d', strtotime( $booking_post_meta['shb_check_out_alt'][0] . ' -1 day' ) );
		
		if(shb_get_date_range_overlap($booking_post_meta['shb_check_in_alt'][0],$checkout2,$checkin,$checkout) == true) {
			$booking_ids[] = $booking_id;
		}
		
	}

	// Get initial quantity of all room IDs
	foreach($room_ids as $key => $val) {
		$available_room_ids[$val]['quantity'] = get_post_meta($val,'shb_room_quantity',TRUE);
	}

	// Get quantity of room IDs based on booking data
	foreach($booking_ids as $key1 => $val1) {
	
		$room_data = get_post_meta($val1,'shb_rooms',TRUE);

		foreach($room_data as $key2 => $val2) {
		
			$available_room_ids[$key2]['quantity'] = $available_room_ids[$key2]['quantity'] - $val2['quantity'];
		
		}
	
	}
	
	return shb_get_translated_wpml_ids_accommodation($available_room_ids,'shb_accommodation');
	
}



/* ----------------------------------------------------------------------------

   Get time elapsed

---------------------------------------------------------------------------- */
function shb_get_time_elapsed($datetime, $full = false) {
    $now = new DateTime;
    $ago = new DateTime($datetime);
    $diff = $now->diff($ago);

    $diff->w = floor($diff->d / 7);
    $diff->d -= $diff->w * 7;

    $string = array(
        'y' => __('year','sohohotel_booking'),
        'm' => __('month','sohohotel_booking'),
        'w' => __('week','sohohotel_booking'),
        'd' => __('day','sohohotel_booking'),
        'h' => __('hour','sohohotel_booking'),
        'i' => __('minute','sohohotel_booking'),
        's' => __('second','sohohotel_booking'),
    );
    foreach ($string as $k => &$v) {
        if ($diff->$k) {
            $v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : '');
        } else {
            unset($string[$k]);
        }
    }

    if (!$full) $string = array_slice($string, 0, 1);
    return $string ? implode(', ', $string) . ' ' . __('ago','sohohotel_booking') : __('just now','sohohotel_booking');
}



/* --------------------------------------------------------------------------------

   Get date range array

-------------------------------------------------------------------------------- */
function shb_get_date_range_array($date_from,$date_to) {
	
	$aryRange=array();
	
	$idate_from=mktime(1,0,0,substr($date_from,5,2),     substr($date_from,8,2),substr($date_from,0,4));
	$idate_to=mktime(1,0,0,substr($date_to,5,2),     substr($date_to,8,2),substr($date_to,0,4));
	
	if ($idate_to>=$idate_from) {
		array_push($aryRange,date('Y-m-d',$idate_from));
		while ($idate_from<$idate_to) {
			$idate_from+=86400;
			array_push($aryRange,date('Y-m-d',$idate_from));
		}
	}

	return $aryRange;

}



/* --------------------------------------------------------------------------------

   Check if date ranges overlap

-------------------------------------------------------------------------------- */
function shb_get_date_range_overlap($from1,$to1,$from2,$to2) {
	
	if ( $from1 <= $to2 && $to1 >= $from2 ) {
		return true;
	} else {
		return false;
	}
	
}



/* --------------------------------------------------------------------------------

   Calculate percentage

-------------------------------------------------------------------------------- */
function shb_calc_percentage($num,$percent) {
	
	return $num - ($percent / 100) * $num;
	
}



/* --------------------------------------------------------------------------------

   Calculate percentage

-------------------------------------------------------------------------------- */
function shb_calc_total_discount($num,$percent) {
	
	return ($percent / 100) * $num;
	
}



/* --------------------------------------------------------------------------------

   Calculate tax percentage

-------------------------------------------------------------------------------- */
function shb_calc_tax_percentage($num,$percent) {
	
	return ($percent / 100) * $num;
	
}



/* --------------------------------------------------------------------------------

   Calculate deposit percentage

-------------------------------------------------------------------------------- */
function shb_calc_deposit_percentage($num,$percent) {
	
	return ($percent / 100) * $num;
	
}



/* --------------------------------------------------------------------------------

   Calculate number of nights

-------------------------------------------------------------------------------- */
function shb_get_booking_nights($check_in,$check_out) {
	
	$check_in = strtotime($check_in);
	$check_out = strtotime($check_out);
	$num_nights = $check_out - $check_in;
	return floor($num_nights/(60*60*24));
	
}



/* ----------------------------------------------------------------------------

   Get all IDs for a specific user ID

---------------------------------------------------------------------------- */
function shb_get_booking_ids_user($userid) {
	
	$booking_ids = get_posts(array(
	    'fields'          => 'ids',
	    'posts_per_page'  => -1,
		'post_type' => 'shb_booking',
		'post_status' => array('shb_confirmed','shb_ical'),
		'meta_query' => array(
		        array(
					'key' => 'shb_userid',
					'value' => $userid
		        ),
		    )
	));
	
	return $booking_ids;
	
}



/* ----------------------------------------------------------------------------

   Get all rooms for booking

---------------------------------------------------------------------------- */
function shb_get_booking_rooms($booking_data) {
	
	if(!empty($booking_data['shb_rooms'][0])) {
		$room_data = unserialize($booking_data['shb_rooms'][0]);
	} else {
		$room_data = array();
	}
	
	$output = '';
	$count = 0;
	$total = count($room_data);
	
	if(shb_room_booking_exist($room_data) == 1) {
		
		foreach ($room_data as $key => $val) {
			
			$count++;
			
			if($count !== $total) {
				$sep = ', ';
			} else {
				$sep = '';
			}
			
			if(!empty($val['quantity'])) {
				
				if(!empty(get_the_title($key))) {
					$output .= get_the_title($key) . $sep;
				} else {
					$output .= '(' . __('no title','sohohotel_booking') . ')' . $sep;
				}
				
			}
		}
		
	} else {
		
		$output .= '-';
		
	}
	
	return $output;
	
}



/* ----------------------------------------------------------------------------

   Get all fees for booking

---------------------------------------------------------------------------- */
function shb_get_booking_fees($booking_data) {
	
	if(!empty($booking_data['shb_fees'][0])) {
		$fee_data = unserialize($booking_data['shb_fees'][0]);
	} else {
		$fee_data = array();
	}
	
	$output = '';
	$count = 0;
	$total = count($fee_data);
	
	if(!empty($fee_data)) {
		
		foreach ($fee_data as $key => $val) {
			
			$count++;
			
			if($count !== $total) {
				$sep = ', ';
			} else {
				$sep = '';
			}
			
			$output .= get_the_title( str_replace('fee_', '', $key) ) . $sep;
			
		}
		
	}
	
	return $output;
	
}



/* ----------------------------------------------------------------------------

   Get all guests for booking

---------------------------------------------------------------------------- */
function shb_get_booking_guests($booking_single_data) {
	
	$output = '';
	$count = 0;
	$total = count($booking_single_data['guestclass_ids']);
	
	foreach ($booking_single_data['guestclass_ids'] as $key3 => $val3) {
		
		$count++;
		
		if($count !== $total) {
			$sep = ', ';
		} else {
			$sep = '';
		}
		
		$guestclass_data = get_post_meta($val3);
		
		if(!empty($booking_single_data['room_data'][$booking_single_data['room_id']]['rooms'][$booking_single_data['room_num']]['guestid_' . $val3])) {
			$output .= $guestclass_data['shb_guestclass_title_plural'][0] . ' ' . $booking_single_data['room_data'][$booking_single_data['room_id']]['rooms'][$booking_single_data['room_num']]['guestid_' . $val3] . $sep;
		}
	
	}
	
	return $output;
	
}



/* ----------------------------------------------------------------------------

   Get all coupons for booking

---------------------------------------------------------------------------- */
function shb_get_booking_coupons($booking_single_data) {
	
	$output = '';
	$count = 0;
	$total = count($booking_single_data['guestclass_ids']);
	
	foreach ($booking_single_data['coupon_data'] as $key => $val) {
		
		$count++;
		
		if($count !== $total) {
			$sep = ', ';
		} else {
			$sep = '';
		}
		
	
		$output .= $val . $sep;
	
	}
	
	return $output;
	
}



/* ----------------------------------------------------------------------------

   Get booking restrictions

---------------------------------------------------------------------------- */
function shb_get_restrictions($room_id) {
	
	$restriction_array = array();
	$checkin_days = array();
	$restriction_check = array();
	$restriction_all = array();
	$restriction_ids = shb_get_all_ids('shb_restriction');
	$season_ids = shb_get_all_ids('shb_season');
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	
	if ($room_id == '') {
		
		foreach ($restriction_ids as $restriction_id) {
				
			foreach ($accommodation_ids as $accommodation_id) {
				
				if (empty(get_post_meta($restriction_id,'shb_accommodation_' . $accommodation_id,TRUE))) {
					$restriction_check[$restriction_id][$accommodation_id] = false;
				} else {
					$restriction_check[$restriction_id][$accommodation_id] = true;
				}
				
			}
				
		}
		
	}
	
	foreach ($restriction_check as $key => $val) {
		
		if ( !in_array(false, $val) ) {
			$restriction_all[] = $key;
		}
		
	}
	
	if ($room_id == '') {
		$restriction_loop = $restriction_all;
	} else {
		$restriction_loop = $restriction_ids;
	}
	
	foreach ($restriction_loop as $val) {
		
		if ( get_post_meta($val,'shb_accommodation_' . $room_id,TRUE) || $room_id == '' ) {
			
			foreach ($season_ids as $season_id) {
				
				if (get_post_meta($val,'shb_season_' . $season_id,TRUE)) {
					
					$restriction_array[$val . '_' . $season_id]["start"] = get_post_meta($season_id,'shb_start_date_alt',TRUE);
					$restriction_array[$val . '_' . $season_id]["end"] = get_post_meta($season_id,'shb_end_date_alt',TRUE);
					$restriction_array[$val . '_' . $season_id]["restrictions"]["min_nights"] = get_post_meta($val,'shb_min_stay',TRUE);
					$restriction_array[$val . '_' . $season_id]["restrictions"]["max_nights"] = get_post_meta($val,'shb_max_stay',TRUE);
					$restriction_array[$val . '_' . $season_id]["restrictions"]["notice"] = get_post_meta($val,'shb_advance_notice',TRUE);
					$days = array(0 => 'sun',1 => 'mon',2 => 'tue',3 => 'wed',4 => 'thu',5 => 'fri',6 => 'sat');
					
					$checkin_days = array();
					
					foreach ($days as $day_index => $day_name) {
						
						if (get_post_meta($val,'shb_check_in_days_' . $day_name,TRUE)) {
							$checkin_days[] = $day_index;
						}
				
					}
			
					$restriction_array[$val . '_' . $season_id]["restrictions"]["checkin_days"] = $checkin_days;
					
				}
				
			}
			
			if (get_post_meta($val,'shb_season_default',TRUE)) {
				
				$start_date = date('Y') . '-' . date('m') . '-01';
				$end_date = (date('Y') + 10) . '-' . date('m') . '-01';
				
				$restriction_array['default']["start"] = $start_date;
				$restriction_array['default']["end"] = $end_date;
				$restriction_array['default']["restrictions"]["min_nights"] = get_post_meta($val,'shb_min_stay',TRUE);
				$restriction_array['default']["restrictions"]["max_nights"] = get_post_meta($val,'shb_max_stay',TRUE);
				$restriction_array['default']["restrictions"]["notice"] = get_post_meta($val,'shb_advance_notice',TRUE);
				$days = array(0 => 'sun',1 => 'mon',2 => 'tue',3 => 'wed',4 => 'thu',5 => 'fri',6 => 'sat');
				
				$checkin_days = array();
				
				foreach ($days as $day_index => $day_name) {
			
					if (get_post_meta($val,'shb_check_in_days_' . $day_name,TRUE)) {
						$checkin_days[] = $day_index;
					}
			
				}
		
				$restriction_array['default']["restrictions"]["checkin_days"] = $checkin_days;
				
			}
			
		}
		
	}
	
	return $restriction_array;
	
}



/* ----------------------------------------------------------------------------

   Get blocked dates

---------------------------------------------------------------------------- */
function shb_get_blocked_dates($room_id) {
	
	if($room_id == '') {
		$accommodation_ids = shb_get_all_ids('shb_accommodation');
	} else {
		$accommodation_ids = array($room_id);
	}
	
	// Get total quantity of all rooms in hotel
	if(!empty($accommodation_ids)) {
		
		foreach ($accommodation_ids as $room) {
			$room_quantity[$room] = get_post_meta($room,'shb_room_quantity',TRUE);
		}
		$room_total = array_sum($room_quantity);
	
		// Create array of all dates in calendar
		$current_month = date('m');
		$current_year = date('Y');
		$end_year = $current_year + 1;
		$end_month = $current_month;
		$checkin = $current_year . '-' . $current_month . '-01';
		$checkout = $end_year . '-' . $end_month . '-01';
		$calendar_dates = shb_get_date_range_array($checkin,$checkout);
		
		// Add room quantity to all dates
		foreach ($calendar_dates as $date) {
			$calendar_dates_qty[$date] = $room_total;
		}
	
		// Get booking IDs which overlap with dates and are confirmed status
		$booking_ids_query = get_posts(array(
		    'fields'          => 'ids',
		    'posts_per_page'  => -1,
			'post_type' => 'shb_booking',
			'post_status' => array('shb_confirmed','shb_ical')
		));
	
		$booking_ids = array();
	
		foreach ($booking_ids_query as $booking_id) {
		
			$booking_post_meta = get_post_meta($booking_id);
		
			if(shb_get_date_range_overlap($booking_post_meta['shb_check_in_alt'][0],$booking_post_meta['shb_check_out_alt'][0],$checkin,$checkout) == true) {
				$booking_ids[] = $booking_id;
			}
		
		}
	
		if($booking_ids) {
		
			if($room_id == '') {
			
				foreach($booking_ids as $val1) {
					
					$temp_quantity = array();
					
					$room_data = get_post_meta($val1,'shb_rooms',TRUE);
					$booking_data[$val1]["checkin"] = get_post_meta($val1,'shb_check_in_alt',TRUE);
					$booking_data[$val1]["checkout"] = get_post_meta($val1,'shb_check_out_alt',TRUE);
		
					foreach($room_data as $key2 => $val2) {
						$temp_quantity[] = $val2['quantity'];
					}
			
					$booking_data[$val1]["qty"] = array_sum($temp_quantity);
			
				}
			
			} else {
			
				foreach($booking_ids as $val1) {
					
					$temp_quantity = array();
					
					$room_data = get_post_meta($val1,'shb_rooms',TRUE);
			
					foreach($room_data as $key2 => $val2) {
				
						if($key2 == $room_id) {
					
							if($val2['quantity'] > 0) {
								$booking_data[$val1]["checkin"] = get_post_meta($val1,'shb_check_in_alt',TRUE);
								$booking_data[$val1]["checkout"] = get_post_meta($val1,'shb_check_out_alt',TRUE);
								$temp_quantity[] = $val2['quantity'];
							}
					
						}
				
					}
				
					if(isset($temp_quantity)) {
						$booking_data[$val1]["qty"] = array_sum($temp_quantity);
					} else {
						$booking_data[$val1]["qty"] = 0;
					}
				
				}
			
			}
		
			// For each date in calendar if date overlaps with booking minus quantity of rooms for that day
			foreach ($calendar_dates_qty as $date => $qty) {
		
				foreach ($booking_data as $booking_id => $booking_dates_qty) {
				
					if(isset($booking_dates_qty["checkin"])) {
						
						$checkout2 = date( 'Y-m-d', strtotime( $booking_dates_qty["checkout"] . ' -1 day' ) );
						
						if( shb_get_date_range_overlap($date,$date,$booking_dates_qty["checkin"],$checkout2) ) {
							$calendar_dates_qty_totals[$date][] = $booking_dates_qty["qty"];
						}
					
					}
			
				}
	
			}
		
			if(isset($calendar_dates_qty_totals)) {
			
				foreach ($calendar_dates_qty_totals as $date => $qty) {
					$calendar_dates_qty_total[$date] = $room_total - array_sum($qty);
				}
	
				// Dates with 0 rooms available are blocked
				$blocked_dates = array();
	
				foreach ($calendar_dates_qty_total as $date => $qty) {
		
					if($qty <= 0) {
						$blocked_dates[] = $date;
					}
		
				}
	
				return $blocked_dates;
			
			} else {
			
				return array();
			
			}
	
		} else {
		
			return array();
		
		}
		
	} else {
		
		return array();
		
	}
	
}



/* ----------------------------------------------------------------------------

   Booking Steps

---------------------------------------------------------------------------- */
function shb_booking_steps($step) {
	
	ob_start();
	include(SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-steps.htm.php');
	return ob_get_clean();
	
}



/* ----------------------------------------------------------------------------

   Booking Page 1

---------------------------------------------------------------------------- */
function shb_booking_page_1($hotel_category) {
	
	ob_start();
	include(SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-step1.htm.php');
	return ob_get_clean();

}



/* ----------------------------------------------------------------------------

   Booking Page 2

---------------------------------------------------------------------------- */
function shb_booking_page_2() {
	
	ob_start();
	echo load_template( SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-step2.htm.php' );
	return ob_get_clean();

}



/* ----------------------------------------------------------------------------

   Booking Page 2 Fees

---------------------------------------------------------------------------- */
function shb_booking_page_2_fees() {
	
	ob_start();
	echo load_template( SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-step2-fees.htm.php' );
	return ob_get_clean();

}



/* ----------------------------------------------------------------------------

   Booking Page 3

---------------------------------------------------------------------------- */
function shb_booking_page_3() {
	
	ob_start();
	echo load_template( SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-step3.htm.php' );
	return ob_get_clean();

}



/* ----------------------------------------------------------------------------

   Booking Page 3 Pay

---------------------------------------------------------------------------- */
function shb_booking_page_3_pay() {
	
	ob_start();
	echo load_template( SHB_PLUGIN_DIR . '/includes/templates/frontend/booking-page/shb-booking-step3-pay.htm.php' );
	return ob_get_clean();

}



/* ----------------------------------------------------------------------------

   Add new booking

---------------------------------------------------------------------------- */
function shb_add_new_booking($booking_data) {
	
	if($booking_data['booking_status'] == 'confirmed') {
		$booking_status = 'shb_confirmed';
	} elseif ($booking_data['booking_status'] == 'ical') {
		$booking_status = 'shb_ical';
	} else {
		$booking_status = 'shb_pending';
	}
	
	if(!empty($booking_data['shb_custom_form_first_name'][0])) {
		$booking_title = $booking_data['shb_custom_form_first_name'][0] . ' ' . $booking_data['shb_custom_form_last_name'][0];
	} else {
		$booking_title = 'iCal';
	}
	
	// Add new post
	$post_id = wp_insert_post(array (
	   'post_type' => 'shb_booking',
	   'post_title' => $booking_title,
	   'post_content' => '',
	   'post_status' => $booking_status,
	   'comment_status' => 'closed',
	   'ping_status' => 'closed',
	));

	// Save custom fields
	if ($post_id) {
		
		if(!empty(get_current_user_id())) {
			add_post_meta($post_id, 'shb_userid', get_current_user_id(), true);
		}
		
		add_post_meta($post_id, 'shb_check_in', shb_get_date($booking_data['checkin']), true);
		add_post_meta($post_id, 'shb_check_out', shb_get_date($booking_data['checkout']), true);
		
		add_post_meta($post_id, 'shb_check_in_alt', $booking_data['booking_price_data']['shb_check_in_alt'][0], true);
		add_post_meta($post_id, 'shb_check_out_alt', $booking_data['booking_price_data']['shb_check_out_alt'][0], true);
		
		add_post_meta($post_id, 'shb_rooms', $booking_data['booking_price_data']['unserialized']['shb_rooms'], true);
		
		if(!empty($booking_data['booking_price_data']['unserialized']['shb_fees'])) {
			add_post_meta($post_id, 'shb_fees', $booking_data['booking_price_data']['unserialized']['shb_fees'], true);
		}
		
		if(!empty($booking_data['booking_price_data']['unserialized']['shb_coupons'])) {
			add_post_meta($post_id, 'shb_booking_coupon', $booking_data['booking_price_data']['unserialized']['shb_coupons'], true);
		}
		
		if(!empty($booking_data['price_breakdown']['grand_total_inc_tax_inc_coupon_discount'])) {
			add_post_meta($post_id, 'shb_amount_due', $booking_data['price_breakdown']['grand_total_inc_tax_inc_coupon_discount'], true);
		}
		
		if(!empty($booking_data['payment_method'])) {
			add_post_meta($post_id, 'shb_payment_method', $booking_data['payment_method'], true);
		}
		
		add_post_meta($post_id, 'shb_amount_paid', '0', true);
		
		if(!empty($booking_data['price_breakdown']['grand_total_inc_tax_inc_coupon_discount'])) {
			add_post_meta($post_id, 'shb_booking_grand_total', $booking_data['price_breakdown']['grand_total_inc_tax_inc_coupon_discount'], true);
		}
		
		if(!empty($booking_data['ical_data'])) {
			add_post_meta($post_id, 'shb_ical_data', $booking_data['ical_data'], true);
		}
		
		$custom_booking_form_fields = array();
		$search = "shb_custom_form_";
		$search_length = strlen($search);
		foreach ($booking_data as $key => $value) {
			if (substr($key, 0, $search_length) == $search) {
				add_post_meta($post_id, $key, $booking_data[$key][0], true);
			}
		}
	}
	
	return $post_id;

}



/* ----------------------------------------------------------------------------

   Update booking payment

---------------------------------------------------------------------------- */
function shb_update_booking_payment($data) {
	
	/*$data = array(
		'booking_id' => 111,
		'payment_method' => 'PayPal',
		'amount_paid' => 100
	)*/
	
	if(!empty(get_post_meta($data['booking_id'],'shb_amount_due',TRUE))) {
		$existing_amount_due = get_post_meta($data['booking_id'],'shb_amount_due',TRUE);
	} else {
		$existing_amount_due = 0.00;
	}
	
	if(!empty(get_post_meta($data['booking_id'],'shb_amount_paid',TRUE))) {
		$existing_amount_paid = get_post_meta($data['booking_id'],'shb_amount_paid',TRUE);
	} else {
		$existing_amount_paid = 0.00;
	}
	
	$amount_due = $existing_amount_due - $data['amount_paid'];
	$amount_paid = $existing_amount_paid + $data['amount_paid'];
	
	if(!empty(get_option('shb_manual_booking_confirmation'))) {
		
		if(get_option('shb_manual_booking_confirmation') == 'yes') {
			$booking_status = 'shb_pending';
		} else {
			$booking_status = 'shb_confirmed';
		}
		
	} else {
		$booking_status = 'shb_confirmed';
	}
	
	if($amount_due == 0) {
		$amount_due = shb_get_price_no_currency_symbol(0);
	}

	wp_update_post(
		array(
			'ID'    =>  $data['booking_id'],
			'post_status'   =>  $booking_status
		)
	);
	
	update_post_meta($data['booking_id'],'shb_amount_paid',$amount_paid);
	update_post_meta($data['booking_id'],'shb_amount_due',$amount_due);
	update_post_meta($data['booking_id'],'shb_payment_method',$data['payment_method']);
	
}



/* ----------------------------------------------------------------------------

   Hotel check

---------------------------------------------------------------------------- */
function shb_hotel_check($array,$category) {
    
	if(!empty($array)) {
		
		foreach ($array as $key => $val) {
        
			if($val->term_id == $category) {
				return true;
			}
		
	    }
		
	}
    
}



/* ----------------------------------------------------------------------------

   Version 3.1 updater

---------------------------------------------------------------------------- */
function shb_version_3_1_updater_check() {
	
	if(empty(get_option( 'shb_3_1_update'))) {
		
		$accommodation_ids = shb_get_all_ids('accommodation');
		$booking_ids = shb_get_all_ids('booking');
	
		if(!empty($accommodation_ids) || !empty($booking_ids)) {
			update_option( 'shb_3_1_update', 'update_required' );
		} else {
			update_option( 'shb_3_1_update', 'update_not_required' );
		}
		
	}

	if(get_option( 'shb_3_1_update') == 'update_required') {
		echo '<div class="notice notice-error"><p>';
		echo 'Database update required, <a target="_blank" href="http://docs.quitenicestuff2.com/sohohotel/update-3-1.html">please read this</a> before clicking the <a target="_blank" href="' . get_home_url() . '?shb_update_3_1=update' . '">update link here</a>';
		echo '</p></div>';
	}
	
}
add_action( 'admin_notices', 'shb_version_3_1_updater_check' );

if ( !empty($_GET['shb_update_3_1']) ) {
	if ( $_GET['shb_update_3_1'] == 'update' ) {
		add_action( 'wp', 'shb_version_3_1_updater' );
	}
}

function shb_version_3_1_updater() {
	
	// Insert adult and child guestclasses
	$adults_id = wp_insert_post(array(
	   'post_type' => 'shb_guestclass',
	   'post_title' => 'Adult',
	   'post_content' => '',
	   'post_status' => 'publish',
	   'comment_status' => 'closed',
	   'ping_status' => 'closed',
	));
	update_post_meta( $adults_id, 'shb_guestclass_title_plural', 'Adults' );
	
	$children_id = wp_insert_post(array(
	   'post_type' => 'shb_guestclass',
	   'post_title' => 'Child',
	   'post_content' => '',
	   'post_status' => 'publish',
	   'comment_status' => 'closed',
	   'ping_status' => 'closed',
	));
	update_post_meta( $children_id, 'shb_guestclass_title_plural', 'Children' );
	
	// Copy accommodation
	$accommodation_ids = shb_get_all_ids('accommodation');

	foreach($accommodation_ids as $key => $val) {
		
		$categories = get_the_terms($val,'accommodation-categories');
		$category_ids = array();
		
		foreach($categories as $category) {
			$category_ids[] = $category->term_id;
		}
		
		$post_id = wp_insert_post(array(
		   'post_type' => 'shb_accommodation',
		   'post_title' => get_the_title($val),
		   'post_content' => get_post_field('post_content', $val),
		   'post_status' => 'publish',
		   'comment_status' => 'closed',
		   'ping_status' => 'closed',
		));
		
		wp_set_post_terms( $post_id, $category_ids, 'accommodation-categories' );
		
		$short_content = get_post_meta($val,'_accommodation_room_excerpt_meta',TRUE);
		update_post_meta( $post_id, 'shb_short_description', $short_content );
		
		$accommodation_featured_image_id = get_post_thumbnail_id($val);
		set_post_thumbnail( $post_id, $accommodation_featured_image_id );
	
	}
	
	// Copy services
	$service_ids = shb_get_all_ids('service');
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	
	foreach($service_ids as $service_id) {
		
		$service_meta = get_post_meta( $service_id, '_service_meta', true );
		
		if($service_meta['price_scheme_1'] == 'flatfee') {
			$price_scheme_1 = 'fee_type1_fixed_amount';
		} elseif($service_meta['price_scheme_1'] == 'perroom') {
			$price_scheme_1 = 'fee_type1_per_room';
		} elseif($service_meta['price_scheme_1'] == 'perperson') {
			$price_scheme_1 = 'fee_type1_per_person';
		}
		
		if($service_meta['price_scheme_2'] == 'pernight') {
			$price_scheme_2 = 'fee_type2_night';
		} elseif($service_meta['price_scheme_2'] == 'perbooking') {
			$price_scheme_2 = 'fee_type2_booking';
		}
		
		if($service_meta['optional_mandatory'] == 'optional') {
			$optional_mandatory = 'yes';
		} elseif($service_meta['optional_mandatory'] == 'mandatory') {
			$optional_mandatory = 'no';
		}
		
		$post_id = wp_insert_post(array(
		   'post_type' => 'shb_fee',
		   'post_title' => get_the_title($service_id),
		   'post_content' => '',
		   'post_status' => 'publish',
		   'comment_status' => 'closed',
		   'ping_status' => 'closed',
		));
		
		update_post_meta( $post_id, 'shb_fee_type1', $price_scheme_1 );
		update_post_meta( $post_id, 'shb_fee_type2', $price_scheme_2 );
		update_post_meta( $post_id, 'shb_fee_optional', $optional_mandatory );
		update_post_meta( $post_id, 'shb_fee_price', $service_meta['price'] );
		update_post_meta( $post_id, 'shb_quantity_selection', 'no' );
		update_post_meta( $post_id, 'shb_min_qty', '1' );
		update_post_meta( $post_id, 'shb_max_qty', '100' );
		update_post_meta( $post_id, 'shb_season_default', 'default' );
		
		foreach($accommodation_ids as $accommodation_id) {
			update_post_meta( $post_id, 'shb_accommodation_' . $accommodation_id, $accommodation_id );
		}
	
	}
	
	// Copy coupons
	$coupon_ids = shb_get_all_ids('coupon');
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	
	foreach($coupon_ids as $coupon_id) {
		
		$coupon_meta = get_post_meta( $coupon_id, '_coupon_meta', true );
		
		$post_id = wp_insert_post(array(
		   'post_type' => 'shb_coupon',
		   'post_title' => get_the_title($coupon_id),
		   'post_content' => '',
		   'post_status' => 'publish',
		   'comment_status' => 'closed',
		   'ping_status' => 'closed',
		));
		
		update_post_meta( $post_id, 'shb_coupon_code', $coupon_meta['coupon_code'] );
		update_post_meta( $post_id, 'shb_usage_limit', '500' );
		
		$expiry_date = date('d/m/Y',strtotime(date("Y-m-d", time()) . " + 365 day"));
		update_post_meta( $post_id, 'shb_expiry_date', $expiry_date );
		
		$expiry_date_alt = date('Y-m-d',strtotime(date("Y-m-d", time()) . " + 365 day"));
		update_post_meta( $post_id, 'shb_expiry_date_alt', $expiry_date_alt );
		
		update_post_meta( $post_id, 'shb_min_nights', '0' );
		update_post_meta( $post_id, 'shb_max_nights', '365' );
	
		if($coupon_meta['coupon_discount_type'] == 'percentage') {
			update_post_meta( $post_id, 'shb_discount_type', 'discount_type_percentage' );
			update_post_meta( $post_id, 'shb_discount_amount', $coupon_meta['amount_flat'] );
		} else {
			update_post_meta( $post_id, 'shb_discount_type', 'discount_type_flat_rate' );
			update_post_meta( $post_id, 'shb_discount_amount', $coupon_meta['amount_percentage'] );
		}
		
		update_post_meta( $post_id, 'shb_season_default', 'default' );
		
		foreach($accommodation_ids as $accommodation_id) {
			update_post_meta( $post_id, 'shb_accommodation_' . $accommodation_id, $accommodation_id );
		}
		
	}
	
	// Copy bookings
	$booking_ids = shb_get_all_ids('booking');
	$service_ids = shb_get_all_ids('service');
	
	foreach($booking_ids as $key => $val) {
	
		$booking_meta = get_post_meta( $val, '_booking_meta', true );
		
		$room_data = json_decode($booking_meta['save_rooms'], true);
		$count = 0;
		
		foreach($room_data as $room_data_val) {
			$count++;
			$room_type = get_page_by_title(get_the_title($room_data_val['room_type']),'OBJECT','shb_accommodation')->ID;
			$room_array[$room_type]['quantity'] = 1;
			$room_array[$room_type]['rooms']['room_' . $count]['guestid_' . $adults_id] = $room_data_val['adults'];
			$room_array[$room_type]['rooms']['room_' . $count]['guestid_' . $children_id] = $room_data_val['children'];
		}
		
		if($booking_meta['booking_status'] == 1) {
			$post_status = 'shb_pending';
		} elseif($booking_meta['booking_status'] == 2) {
			$post_status = 'shb_confirmed';
		} elseif($booking_meta['booking_status'] == 3) {
			$post_status = 'shb_cancelled';
		} else {
			$post_status = 'shb_confirmed';
		}
		
		$post_id = wp_insert_post(array(
		   'post_type' => 'shb_booking',
		   'post_title' => get_the_title($val),
		   'post_content' => '',
		   'post_status' => $post_status,
		   'comment_status' => 'closed',
		   'ping_status' => 'closed',
		));
		
		$grand_total = $booking_meta['outstanding_amount'] + $booking_meta['amount_paid'];
		update_post_meta( $post_id, 'shb_booking_grand_total', $grand_total );
		update_post_meta( $post_id, 'shb_check_in', shb_get_date($booking_meta['check_in']) );
		update_post_meta( $post_id, 'shb_check_out', shb_get_date($booking_meta['check_out']) );
		update_post_meta( $post_id, 'shb_check_in_alt', $booking_meta['check_in'] );
		update_post_meta( $post_id, 'shb_check_out_alt', $booking_meta['check_out'] );
		update_post_meta( $post_id, 'shb_amount_due', $booking_meta['outstanding_amount'] );
		update_post_meta( $post_id, 'shb_amount_paid', $booking_meta['amount_paid'] );
		update_post_meta( $post_id, 'shb_payment_method', $booking_meta['payment_method'] );
		update_post_meta( $post_id, 'shb_rooms', $room_array );
		
		$custom_fields = shb_custom_form_field_names();
		foreach($custom_fields['fields'] as $custom_field) {
			$custom_field_explode = explode('custom_form_',$custom_field['id']);
			update_post_meta( $post_id, 'shb_' . $custom_field['id'], $booking_meta[$custom_field_explode[1]] );
		}
		
		$update_title = array(
			'ID'           => $post_id,
			'post_title'   => $booking_meta['first_name'] . ' ' . $booking_meta['last_name'],
			'post_content' => '',
		);
		
		wp_update_post( $update_title );
		
	}
	
	update_option( 'shb_3_1_update', 'update_not_required' );
	echo 'Update complete';
	exit();
	
}