<?php



/* ----------------------------------------------------------------------------

   Register post type

---------------------------------------------------------------------------- */
add_action( 'init', 'shb_coupon_post_type' );
function shb_coupon_post_type() {
	
	$labels = array(
        'name'                  => __('Coupons','sohohotel_booking'),
        'singular_name'         => __('Coupon','sohohotel_booking'),
        'menu_name'             => __('Coupons','sohohotel_booking'),
        'parent_item_colon'     => __('Parent Coupon:','sohohotel_booking'),
        'all_items'             => __('Coupons','sohohotel_booking'),
        'view_item'             => __('View Coupon','sohohotel_booking'),
        'add_new_item'          => __('Add New Coupon','sohohotel_booking'),
        'add_new'               => __('Add New','sohohotel_booking'),
        'edit_item'             => __('Edit Coupon','sohohotel_booking'),
        'update_item'           => __('Update Coupon','sohohotel_booking'),
        'search_items'          => __('Search Coupon','sohohotel_booking'),
        'not_found'             => __('Not found','sohohotel_booking'),
        'not_found_in_trash'    => __('Not found in Trash','sohohotel_booking'),
    );

    $args = array(
        'label'                 => __('Coupon','sohohotel_booking'),
        'description'           => '',
        'labels'                => $labels,
        'supports'              => array('title'),
        'hierarchical'          => false,
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'shb_booking_calendar',
        'show_in_nav_menus'     => false,
        'show_in_admin_bar'     => true,
        'menu_position'         => 5,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => false,
        'capability_type'       => 'page',
		'rewrite' => array('slug' => esc_html__( 'coupon', 'sohohotel_booking' ),'with_front' => false),
    );

    register_post_type( 'shb_coupon', $args );
	
}



/* ----------------------------------------------------------------------------

   Meta boxes

---------------------------------------------------------------------------- */
add_action('add_meta_boxes', 'shb_coupon_meta_init');
function shb_coupon_meta_init() {
	
	add_meta_box(
		'shb_coupon_settings',
		__('Coupon Settings','sohohotel_booking'),
		'shb_coupon_show_meta_box',
		'shb_coupon',
		'normal',
		'high'
	);
	
    add_action('save_post','shb_coupon_meta_save');

}



/* ----------------------------------------------------------------------------

   Meta box content

---------------------------------------------------------------------------- */
function shb_coupon_show_meta_box() {
	
    global $post;
    $coupon_data = get_post_meta($post->ID);
    include(SHB_PLUGIN_DIR . '/includes/templates/backend/coupon/shb-coupon.htm.php');
    echo '<input type="hidden" name="coupon_meta_noncename" value="' . wp_create_nonce(__FILE__) . '" />';

}



/* ----------------------------------------------------------------------------

   Post type custom columns

---------------------------------------------------------------------------- */
add_filter( 'manage_shb_coupon_posts_columns', 'shb_coupon_custom_columns' );
function shb_coupon_custom_columns($columns) {
	
	unset($columns['date']);
    unset( $columns['author'] );
    $columns['coupon_usage_limit'] = __( 'Usage Limit', 'sohohotel_booking' );
    $columns['coupon_expiry_date'] = __( 'Expiry Date', 'sohohotel_booking' );
	$columns['coupon_min_max_stay'] = __( 'Min/Max Stay', 'sohohotel_booking' );
	$columns['coupon_discount'] = __( 'Discount', 'sohohotel_booking' );
	$columns['coupon_season'] = __( 'Seasons', 'sohohotel_booking' );
	$columns['coupon_rooms'] = __( 'Rooms', 'sohohotel_booking' );
    return $columns;
	
}



/* ----------------------------------------------------------------------------

   Custom columns content

---------------------------------------------------------------------------- */
add_action( 'manage_shb_coupon_posts_custom_column' , 'shb_coupon_custom_columns_content', 10, 2 );
function shb_coupon_custom_columns_content( $column, $post_id ) {
	
	$coupon_meta = get_post_meta(get_the_id());
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	$season_ids = shb_get_all_ids('shb_season');

    switch ( $column ) {
		
		case 'coupon_usage_limit' :
			
			if (!empty($coupon_meta['shb_used'][0])) {
				$used = $coupon_meta['shb_used'][0];
			} else {
				$used = 0;
			}
			
			echo $coupon_meta['shb_usage_limit'][0] . ' (' . $used . ' ' . __('used','sohohotel_booking') . ')';
			break;
			
		case 'coupon_expiry_date' :
			echo $coupon_meta['shb_expiry_date'][0];
			break;
		
		case 'coupon_min_max_stay' :
			echo $coupon_meta['shb_min_nights'][0] . '/' . $coupon_meta['shb_max_nights'][0] . ' ' . __('night(s)','sohohotel_booking');
			break;
			
		case 'coupon_discount' :
			$discount_type = shb_get_display_text($coupon_meta['shb_discount_type'][0]);
			echo $discount_type;
			break;
				
		case 'coupon_season' :
			echo shb_get_column_selected_fields($coupon_meta,'season',$season_ids,false);
			break;
		
		case 'coupon_rooms' :
			echo shb_get_column_selected_fields($coupon_meta,'accommodation',$accommodation_ids,true);
			break;
		
    }
	
}



/* ----------------------------------------------------------------------------

   Disable quick edit

---------------------------------------------------------------------------- */
add_filter( 'post_row_actions', 'shb_coupon_disable_quick_edit', 10, 2 );
function shb_coupon_disable_quick_edit( $actions = array(), $post = null ) {

    if ( ! is_post_type_archive( 'shb_coupon' ) ) {
        return $actions;
    }

    if ( isset( $actions['inline hide-if-no-js'] ) ) {
        unset( $actions['inline hide-if-no-js'] );
    }

    return $actions;

}



/* ----------------------------------------------------------------------------

   Remove date filter

---------------------------------------------------------------------------- */ 
function shb_coupon_remove_date_filter(){
	
	$screen = get_current_screen();
	
    if ( $screen->post_type == 'shb_coupon'){
		add_filter('months_dropdown_results', '__return_empty_array');
	}
	
}

add_action('admin_head', 'shb_coupon_remove_date_filter');



/* ----------------------------------------------------------------------------

   Save meta content

---------------------------------------------------------------------------- */
add_action('save_post', 'shb_coupon_meta_save');
function shb_coupon_meta_save( $post_id ){
	
	$prefix = 'shb';

	if ( isset($_POST['coupon_meta_noncename'])) {
		
		if (!wp_verify_nonce($_POST['coupon_meta_noncename'],__FILE__)) {
			return $post_id;
		}

		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
		
		$coupon_data = get_post_meta($post_id);
		foreach($coupon_data as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				if(empty($_POST[$key])) {
					delete_post_meta($post_id,$key);
				} 
		    }
		}
		
		foreach($_POST as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				update_post_meta($post_id,$key,$_POST[$key]);
		    }
		}

	}

}