<?php



/* ----------------------------------------------------------------------------

   Register post type

---------------------------------------------------------------------------- */
add_action( 'init', 'shb_discount_post_type' );
function shb_discount_post_type() {
	
	$labels = array(
        'name'                  => __('Discount','sohohotel_booking'),
        'singular_name'         => __('Discount','sohohotel_booking'),
        'menu_name'             => __('Discounts','sohohotel_booking'),
        'parent_item_colon'     => __('Parent Discount:','sohohotel_booking'),
        'all_items'             => __('Discounts','sohohotel_booking'),
        'view_item'             => __('View Discount','sohohotel_booking'),
        'add_new_item'          => __('Add New Discount','sohohotel_booking'),
        'add_new'               => __('Add New','sohohotel_booking'),
        'edit_item'             => __('Edit Discount','sohohotel_booking'),
        'update_item'           => __('Update Discount','sohohotel_booking'),
        'search_items'          => __('Search Discount','sohohotel_booking'),
        'not_found'             => __('Not found','sohohotel_booking'),
        'not_found_in_trash'    => __('Not found in Trash','sohohotel_booking'),
    );

    $args = array(
        'label'                 => __('Discount','sohohotel_booking'),
        'description'           => '',
        'labels'                => $labels,
        'supports'              => array('title'),
        'hierarchical'          => false,
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'shb_booking_calendar',
        'show_in_nav_menus'     => false,
        'show_in_admin_bar'     => true,
        'menu_position'         => 5,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => false,
        'capability_type'       => 'page',
		'rewrite' => array('slug' => esc_html__( 'discount', 'sohohotel_booking' ),'with_front' => false),
    );

    register_post_type( 'shb_discount', $args );
	
}



/* ----------------------------------------------------------------------------

   Meta boxes

---------------------------------------------------------------------------- */
add_action('add_meta_boxes', 'shb_discount_meta_init');
function shb_discount_meta_init() {
	
	add_meta_box(
		'shb_discount_settings',
		__('Discount Settings','sohohotel_booking'),
		'shb_discount_show_meta_box',
		'shb_discount',
		'normal',
		'high'
	);
	
    add_action('save_post','shb_discount_meta_save');

}



/* ----------------------------------------------------------------------------

   Meta box content

---------------------------------------------------------------------------- */
function shb_discount_show_meta_box() {
	
    global $post;
    $discount_data = get_post_meta($post->ID);
    include(SHB_PLUGIN_DIR . '/includes/templates/backend/discount/shb-discount.htm.php');
    echo '<input type="hidden" name="discount_meta_noncename" value="' . wp_create_nonce(__FILE__) . '" />';

}



/* ----------------------------------------------------------------------------

   Post type custom columns

---------------------------------------------------------------------------- */
add_filter( 'manage_shb_discount_posts_columns', 'shb_discount_custom_columns' );
function shb_discount_custom_columns($columns) {
	
	unset($columns['date']);
    unset( $columns['author'] );
	$columns['discount_type'] = __( 'Type', 'sohohotel_booking' );
	$columns['discount_nights'] = __( 'Night(s)', 'sohohotel_booking' );
    $columns['discount_conjunction'] = __( 'Conjunction', 'sohohotel_booking' );
	$columns['discount_season'] = __( 'Season', 'sohohotel_booking' );
	$columns['discount_rooms'] = __( 'Rooms', 'sohohotel_booking' );
    return $columns;
	
}



/* ----------------------------------------------------------------------------

   Custom columns content

---------------------------------------------------------------------------- */
add_action( 'manage_shb_discount_posts_custom_column' , 'shb_discount_custom_columns_content', 10, 2 );
function shb_discount_custom_columns_content( $column, $post_id ) {
	
	$discount_meta = get_post_meta(get_the_id());
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	$season_ids = shb_get_all_ids('shb_season');

    switch ( $column ) {
		
        case 'discount_type' :
			echo shb_get_display_text($discount_meta['shb_discount_type'][0]);
			break;
			
		case 'discount_nights' :
			
			if ($discount_meta['shb_discount_type'][0] == 'duration') {
				echo $discount_meta['shb_discount_duration'][0];
			} elseif ($discount_meta['shb_discount_type'][0] == 'early') {
				echo $discount_meta['shb_discount_early'][0];
			} else {
				echo $discount_meta['shb_discount_late'][0];
			}
		
			break;
		
		case 'discount_conjunction' :
			if(!empty($discount_meta['shb_discount_conjunction'][0])) {
				echo shb_get_display_text($discount_meta['shb_discount_conjunction'][0]);
			}
			break;
		
        case 'discount_season' :
			echo shb_get_column_selected_fields($discount_meta,'season',$season_ids,false);
			break;
		
		case 'discount_rooms' :
			echo shb_get_column_selected_fields($discount_meta,'accommodation',$accommodation_ids,true);
			break;
		
    }
	
}



/* ----------------------------------------------------------------------------

   Disable quick edit

---------------------------------------------------------------------------- */
add_filter( 'post_row_actions', 'shb_discount_disable_quick_edit', 10, 2 );
function shb_discount_disable_quick_edit( $actions = array(), $post = null ) {

    if ( ! is_post_type_archive( 'shb_discount' ) ) {
        return $actions;
    }

    if ( isset( $actions['inline hide-if-no-js'] ) ) {
        unset( $actions['inline hide-if-no-js'] );
    }

    return $actions;

}



/* ----------------------------------------------------------------------------

   Remove date filter

---------------------------------------------------------------------------- */ 
function shb_discount_remove_date_filter(){
	
	$screen = get_current_screen();
	
    if ( $screen->post_type == 'shb_discount'){
		add_filter('months_dropdown_results', '__return_empty_array');
	}
	
}

add_action('admin_head', 'shb_discount_remove_date_filter');



/* ----------------------------------------------------------------------------

   Save meta content

---------------------------------------------------------------------------- */
add_action('save_post', 'shb_discount_meta_save');
function shb_discount_meta_save( $post_id ){
	
	$prefix = 'shb';

	if ( isset($_POST['discount_meta_noncename'])) {
		
		if (!wp_verify_nonce($_POST['discount_meta_noncename'],__FILE__)) {
			return $post_id;
		}

		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
		
		$discount_data = get_post_meta($post_id);
		foreach($discount_data as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				if(empty($_POST[$key])) {
					delete_post_meta($post_id,$key);
				} 
		    }
		}
		
		foreach($_POST as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				update_post_meta($post_id,$key,$_POST[$key]);
		    }
		}

	}

}