<?php



/* ----------------------------------------------------------------------------

   Register post type

---------------------------------------------------------------------------- */
add_action( 'init', 'shb_fee_post_type' );
function shb_fee_post_type() {
	
	$labels = array(
        'name'                  => __('Fees','sohohotel_booking'),
        'singular_name'         => __('Fee','sohohotel_booking'),
        'menu_name'             => __('Fees','sohohotel_booking'),
        'parent_item_colon'     => __('Parent Fee:','sohohotel_booking'),
        'all_items'             => __('Fees','sohohotel_booking'),
        'view_item'             => __('View Fee','sohohotel_booking'),
        'add_new_item'          => __('Add New Fee','sohohotel_booking'),
        'add_new'               => __('Add New','sohohotel_booking'),
        'edit_item'             => __('Edit Fee','sohohotel_booking'),
        'update_item'           => __('Update Fee','sohohotel_booking'),
        'search_items'          => __('Search Fee','sohohotel_booking'),
        'not_found'             => __('Not found','sohohotel_booking'),
        'not_found_in_trash'    => __('Not found in Trash','sohohotel_booking'),
    );

    $args = array(
        'label'                 => __('Fee','sohohotel_booking'),
        'description'           => '',
        'labels'                => $labels,
        'supports'              => array('title'),
        'hierarchical'          => false,
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'shb_booking_calendar',
        'show_in_nav_menus'     => false,
        'show_in_admin_bar'     => true,
        'menu_position'         => 5,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => false,
        'capability_type'       => 'page',
		'rewrite' => array('slug' => esc_html__( 'fee', 'sohohotel_booking' ),'with_front' => false),
    );

    register_post_type( 'shb_fee', $args );
	
}



/* ----------------------------------------------------------------------------

   Meta boxes

---------------------------------------------------------------------------- */
add_action('add_meta_boxes', 'shb_fee_meta_init');
function shb_fee_meta_init() {
	
	add_meta_box(
		'shb_fee_settings',
		__('Fee Settings','sohohotel_booking'),
		'shb_fee_show_meta_box',
		'shb_fee',
		'normal',
		'high'
	);
	
    add_action('save_post','shb_fee_meta_save');

}



/* ----------------------------------------------------------------------------

   Meta box content

---------------------------------------------------------------------------- */
function shb_fee_show_meta_box() {
	
    global $post;
    $fee_data = get_post_meta($post->ID);
    include(SHB_PLUGIN_DIR . '/includes/templates/backend/fee/shb-fee.htm.php');
    echo '<input type="hidden" name="fee_meta_noncename" value="' . wp_create_nonce(__FILE__) . '" />';

}



/* ----------------------------------------------------------------------------

   Post type custom columns

---------------------------------------------------------------------------- */
add_filter( 'manage_shb_fee_posts_columns', 'shb_fee_custom_columns' );
function shb_fee_custom_columns($columns) {
	
	unset($columns['date']);
    unset( $columns['author'] );
	$columns['fee_price'] = __( 'Price', 'sohohotel_booking' );
	$columns['fee_optional'] = __( 'Optional', 'sohohotel_booking' );
	$columns['fee_quantityselect'] = __( 'Quantity Selection', 'sohohotel_booking' );
    $columns['fee_season'] = __( 'Seasons', 'sohohotel_booking' );
    $columns['fee_rooms'] = __( 'Rooms', 'sohohotel_booking' );
    return $columns;
	
}



/* ----------------------------------------------------------------------------

   Custom columns content

---------------------------------------------------------------------------- */
add_action( 'manage_shb_fee_posts_custom_column' , 'shb_fee_custom_columns_content', 10, 2 );
function shb_fee_custom_columns_content( $column, $post_id ) {
	
	$fee_meta = get_post_meta(get_the_id());
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	$season_ids = shb_get_all_ids('shb_season');

    switch ( $column ) {
		
        case 'fee_price' :
			$price_type1 = shb_get_display_text($fee_meta['shb_fee_type1'][0]);
			$price_type2 = shb_get_display_text($fee_meta['shb_fee_type2'][0]);
			echo shb_get_price($fee_meta['shb_fee_price'][0]) . ' / ' . $price_type1 . ' / ' . __( 'Per', 'sohohotel_booking' ) . ' ' . $price_type2;
			break;
			
		case 'fee_optional' :
			echo shb_get_display_text($fee_meta['shb_fee_optional'][0]);
			break;
			
		case 'fee_quantityselect' :
			if($fee_meta['shb_fee_optional'][0] == 'yes') {
				echo shb_get_display_text($fee_meta['shb_quantity_selection'][0]);
			} else {
				echo '-';
			}
			break;
		
        case 'fee_season' :	
			echo shb_get_column_selected_fields($fee_meta,'season',$season_ids,false);
			break;
		
		case 'fee_rooms' :
			echo shb_get_column_selected_fields($fee_meta,'accommodation',$accommodation_ids,true);
			break;
		
    }
	
}



/* ----------------------------------------------------------------------------

   Disable quick edit

---------------------------------------------------------------------------- */
add_filter( 'post_row_actions', 'shb_fee_disable_quick_edit', 10, 2 );
function shb_fee_disable_quick_edit( $actions = array(), $post = null ) {

    if ( ! is_post_type_archive( 'shb_fee' ) ) {
        return $actions;
    }

    if ( isset( $actions['inline hide-if-no-js'] ) ) {
        unset( $actions['inline hide-if-no-js'] );
    }

    return $actions;

}



/* ----------------------------------------------------------------------------

   Remove date filter

---------------------------------------------------------------------------- */ 
function shb_fee_remove_date_filter(){
	
	$screen = get_current_screen();
	
    if ( $screen->post_type == 'shb_fee'){
		add_filter('months_dropdown_results', '__return_empty_array');
	}
	
}

add_action('admin_head', 'shb_fee_remove_date_filter');



/* ----------------------------------------------------------------------------

   Make custom columns sortable

---------------------------------------------------------------------------- */
add_filter( 'manage_edit-shb_fee_sortable_columns', 'sortable_shb_fee_column' );
function sortable_shb_fee_column( $columns ) {
    
	$columns['fee_price'] = 'fee_price';
    return $columns;
	
}

add_action( 'pre_get_posts', 'fee_orderby' );
function fee_orderby( $query ) {
	
	if( ! is_admin() )
        return;
 
    $orderby = $query->get( 'orderby');
 
    if( 'fee_price' == $orderby ) {
        $query->set('meta_key','shb_fee_price');
        $query->set('orderby','meta_value_num');
    }
	
}



/* ----------------------------------------------------------------------------

   Save meta content

---------------------------------------------------------------------------- */
add_action('save_post', 'shb_fee_meta_save');
function shb_fee_meta_save( $post_id ){
	
	$prefix = 'shb';

	if ( isset($_POST['fee_meta_noncename'])) {
		
		if (!wp_verify_nonce($_POST['fee_meta_noncename'],__FILE__)) {
			return $post_id;
		}

		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
		
		$fee_data = get_post_meta($post_id);
		foreach($fee_data as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				if(empty($_POST[$key])) {
					delete_post_meta($post_id,$key);
				} 
		    }
		}
		
		foreach($_POST as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				update_post_meta($post_id,$key,$_POST[$key]);
		    }
		}
		
		// Find and replace decimal and thousand separators
		$shb_fee_price = $_POST['shb_fee_price'];
		
		if(!empty(get_option('shb_price_thousand_separator'))) {
			$thousand_separator = get_option('shb_price_thousand_separator');
		} else {
			$thousand_separator = ',';
		}
		
		if(!empty(get_option('shb_price_decimal_separator'))) {
			$decimal_separator = get_option('shb_price_decimal_separator');
		} else {
			$decimal_separator = '.';
		}
		
		$search_strings = array($thousand_separator,$decimal_separator);
		$replace_strings = array('','.');

		$shb_fee_price = str_replace($search_strings,$replace_strings,$shb_fee_price);	
		
		update_post_meta($post_id,'shb_fee_price',$shb_fee_price);	

	}

}