<?php



/* ----------------------------------------------------------------------------

   Register post type

---------------------------------------------------------------------------- */
add_action( 'init', 'shb_restriction_post_type' );
function shb_restriction_post_type() {
	
	$labels = array(
        'name'                  => __('Restrictions','sohohotel_booking'),
        'singular_name'         => __('Restriction','sohohotel_booking'),
        'menu_name'             => __('Restriction','sohohotel_booking'),
        'parent_item_colon'     => __('Parent Restriction:','sohohotel_booking'),
        'all_items'             => __('Restrictions','sohohotel_booking'),
        'view_item'             => __('View Restriction','sohohotel_booking'),
        'add_new_item'          => __('Add New Restriction','sohohotel_booking'),
        'add_new'               => __('Add New','sohohotel_booking'),
        'edit_item'             => __('Edit Restriction','sohohotel_booking'),
        'update_item'           => __('Update Restriction','sohohotel_booking'),
        'search_items'          => __('Search Restriction','sohohotel_booking'),
        'not_found'             => __('Not found','sohohotel_booking'),
        'not_found_in_trash'    => __('Not found in Trash','sohohotel_booking'),
    );

    $args = array(
        'label'                 => __('Restriction','sohohotel_booking'),
        'description'           => '',
        'labels'                => $labels,
        'supports'              => array('title'),
        'hierarchical'          => false,
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'shb_booking_calendar',
        'show_in_nav_menus'     => false,
        'show_in_admin_bar'     => true,
        'menu_position'         => 5,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => false,
        'capability_type'       => 'page',
		'rewrite' => array('slug' => esc_html__( 'restriction', 'sohohotel_booking' ),'with_front' => false),
    );

    register_post_type( 'shb_restriction', $args );
	
}



/* ----------------------------------------------------------------------------

   Meta boxes

---------------------------------------------------------------------------- */
add_action('add_meta_boxes', 'shb_restriction_meta_init');
function shb_restriction_meta_init() {
	
	add_meta_box(
		'shb_restriction_settings',
		__('Restriction Settings','sohohotel_booking'),
		'shb_restriction_show_meta_box',
		'shb_restriction',
		'normal',
		'high'
	);
	
    add_action('save_post','shb_restriction_meta_save');

}



/* ----------------------------------------------------------------------------

   Meta box content

---------------------------------------------------------------------------- */
function shb_restriction_show_meta_box() {
	
    global $post;
    $restriction_data = get_post_meta($post->ID);
    include(SHB_PLUGIN_DIR . '/includes/templates/backend/restriction/shb-restriction.htm.php');
    echo '<input type="hidden" name="restriction_meta_noncename" value="' . wp_create_nonce(__FILE__) . '" />';

}



/* ----------------------------------------------------------------------------

   Post type custom columns

---------------------------------------------------------------------------- */
add_filter( 'manage_shb_restriction_posts_columns', 'shb_restriction_custom_columns' );
function shb_restriction_custom_columns($columns) {
	
	unset($columns['date']);
    unset( $columns['author'] );
    $columns['restriction_min_max_stay'] = __( 'Min/Max Stay', 'sohohotel_booking' );
	$columns['restriction_advance_notice'] = __( 'Notice', 'sohohotel_booking' );
	$columns['restriction_check_in_days'] = __( 'Check In Days', 'sohohotel_booking' );
	$columns['restriction_season'] = __( 'Seasons', 'sohohotel_booking' );
	$columns['restriction_rooms'] = __( 'Rooms', 'sohohotel_booking' );
    return $columns;
	
}



/* ----------------------------------------------------------------------------

   Custom columns content

---------------------------------------------------------------------------- */
add_action( 'manage_shb_restriction_posts_custom_column' , 'shb_restriction_custom_columns_content', 10, 2 );
function shb_restriction_custom_columns_content( $column, $post_id ) {
	
	$restriction_meta = get_post_meta(get_the_id());
	$accommodation_ids = shb_get_all_ids('shb_accommodation');
	$season_ids = shb_get_all_ids('shb_season');

    switch ( $column ) {
		
        case 'restriction_min_max_stay' :
			echo $restriction_meta['shb_min_stay'][0] . '/' . $restriction_meta['shb_max_stay'][0] . ' ' . __( 'night(s)', 'sohohotel_booking' );
			break;
			
		case 'restriction_advance_notice' :
			echo $restriction_meta['shb_advance_notice'][0] . ' ' . __( 'night(s)', 'sohohotel_booking' );
			break;
			
		case 'restriction_check_in_days' :
			$open = '<span class="shb-check-in-days-column">';
			$close = '<span>, </span></span>';
			if ( !empty($restriction_meta['shb_check_in_days_mon'][0]) ) {echo $open . __('Mo','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_tue'][0]) ) {echo $open . __('Tu','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_wed'][0]) ) {echo $open . __('We','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_thu'][0]) ) {echo $open . __('Th','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_fri'][0]) ) {echo $open . __('Fr','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_sat'][0]) ) {echo $open . __('Sa','sohohotel_booking') . $close;}
			if ( !empty($restriction_meta['shb_check_in_days_sun'][0]) ) {echo $open . __('Su','sohohotel_booking') . $close;}
			break;
		
		case 'restriction_season' :
			echo shb_get_column_selected_fields($restriction_meta,'season',$season_ids,false);
			break;
		
		case 'restriction_rooms' :
			echo shb_get_column_selected_fields($restriction_meta,'accommodation',$accommodation_ids,true);
			break;
		
    }
	
}



/* ----------------------------------------------------------------------------

   Disable quick edit

---------------------------------------------------------------------------- */
add_filter( 'post_row_actions', 'shb_restriction_disable_quick_edit', 10, 2 );
function shb_restriction_disable_quick_edit( $actions = array(), $post = null ) {

    if ( ! is_post_type_archive( 'shb_restriction' ) ) {
        return $actions;
    }

    if ( isset( $actions['inline hide-if-no-js'] ) ) {
        unset( $actions['inline hide-if-no-js'] );
    }

    return $actions;

}



/* ----------------------------------------------------------------------------

   Remove date filter

---------------------------------------------------------------------------- */ 
function shb_restriction_remove_date_filter(){
	
	$screen = get_current_screen();
	
    if ( $screen->post_type == 'shb_restriction'){
		add_filter('months_dropdown_results', '__return_empty_array');
	}
	
}

add_action('admin_head', 'shb_restriction_remove_date_filter');



/* ----------------------------------------------------------------------------

   Save meta content

---------------------------------------------------------------------------- */
add_action('save_post', 'shb_restriction_meta_save');
function shb_restriction_meta_save( $post_id ){
	
	$prefix = 'shb';

	if ( isset($_POST['restriction_meta_noncename'])) {
		
		if (!wp_verify_nonce($_POST['restriction_meta_noncename'],__FILE__)) {
			return $post_id;
		}

		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
		
		$restriction_data = get_post_meta($post_id);
		foreach($restriction_data as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				if(empty($_POST[$key])) {
					delete_post_meta($post_id,$key);
				} 
		    }
		}
		
		foreach($_POST as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				update_post_meta($post_id,$key,$_POST[$key]);
		    }
		}

	}

}