<?php



/* ----------------------------------------------------------------------------

   Register post type

---------------------------------------------------------------------------- */
add_action( 'init', 'shb_tax_post_type' );
function shb_tax_post_type() {
	
	$labels = array(
        'name'                  => __('Taxes','sohohotel_booking'),
        'singular_name'         => __('Tax','sohohotel_booking'),
        'menu_name'             => __('Taxes','sohohotel_booking'),
        'parent_item_colon'     => __('Parent Tax:','sohohotel_booking'),
        'all_items'             => __('Taxes','sohohotel_booking'),
        'view_item'             => __('View Tax','sohohotel_booking'),
        'add_new_item'          => __('Add New Tax','sohohotel_booking'),
        'add_new'               => __('Add New','sohohotel_booking'),
        'edit_item'             => __('Edit Tax','sohohotel_booking'),
        'update_item'           => __('Update Tax','sohohotel_booking'),
        'search_items'          => __('Search Tax','sohohotel_booking'),
        'not_found'             => __('Not found','sohohotel_booking'),
        'not_found_in_trash'    => __('Not found in Trash','sohohotel_booking'),
    );

    $args = array(
        'label'                 => __('Tax','sohohotel_booking'),
        'description'           => '',
        'labels'                => $labels,
        'supports'              => array('title'),
        'hierarchical'          => false,
        'public'                => false,
        'show_ui'               => true,
        'show_in_menu'          => 'shb_booking_calendar',
        'show_in_nav_menus'     => false,
        'show_in_admin_bar'     => true,
        'menu_position'         => 5,
        'can_export'            => true,
        'has_archive'           => true,
        'exclude_from_search'   => true,
        'publicly_queryable'    => false,
        'capability_type'       => 'page',
		'rewrite' => array('slug' => esc_html__( 'tax', 'sohohotel_booking' ),'with_front' => false),
    );

    register_post_type( 'shb_tax', $args );
	
}



/* ----------------------------------------------------------------------------

   Meta boxes

---------------------------------------------------------------------------- */
add_action('add_meta_boxes', 'shb_tax_meta_init');
function shb_tax_meta_init() {
	
	add_meta_box(
		'shb_tax_settings',
		__('Tax Settings','sohohotel_booking'),
		'shb_tax_show_meta_box',
		'shb_tax',
		'normal',
		'high'
	);
	
    add_action('save_post','shb_tax_meta_save');

}



/* ----------------------------------------------------------------------------

   Meta box content

---------------------------------------------------------------------------- */
function shb_tax_show_meta_box() {
	
    global $post;
    $tax_data = get_post_meta($post->ID);
    include(SHB_PLUGIN_DIR . '/includes/templates/backend/tax/shb-tax.htm.php');
    echo '<input type="hidden" name="tax_meta_noncename" value="' . wp_create_nonce(__FILE__) . '" />';

}



/* ----------------------------------------------------------------------------

   Post type custom columns

---------------------------------------------------------------------------- */
add_filter( 'manage_shb_tax_posts_columns', 'shb_tax_custom_columns' );
function shb_tax_custom_columns($columns) {
	
	unset($columns['date']);
    unset( $columns['author'] );
    $columns['tax_rate'] = __( 'Tax Rate', 'sohohotel_booking' );
    return $columns;
	
}



/* ----------------------------------------------------------------------------

   Custom columns content

---------------------------------------------------------------------------- */
add_action( 'manage_shb_tax_posts_custom_column' , 'shb_tax_custom_columns_content', 10, 2 );
function shb_tax_custom_columns_content( $column, $post_id ) {
	
	$tax_meta = get_post_meta(get_the_id());
	$accommodation_ids = shb_get_all_ids('shb_accommodation');

    switch ( $column ) {
		
        case 'tax_rate' :
			echo $tax_meta['shb_tax_rate'][0] . '%';
			break;
		
		case 'tax_type' :
			$tax_type = shb_get_display_text($tax_meta['shb_tax_type'][0]);
			echo $tax_type;
			break;
		
    }
	
}



/* ----------------------------------------------------------------------------

   Disable quick edit

---------------------------------------------------------------------------- */
add_filter( 'post_row_actions', 'shb_tax_disable_quick_edit', 10, 2 );
function shb_tax_disable_quick_edit( $actions = array(), $post = null ) {

    if ( ! is_post_type_archive( 'shb_tax' ) ) {
        return $actions;
    }

    if ( isset( $actions['inline hide-if-no-js'] ) ) {
        unset( $actions['inline hide-if-no-js'] );
    }

    return $actions;

}



/* ----------------------------------------------------------------------------

   Remove date filter

---------------------------------------------------------------------------- */ 
function shb_tax_remove_date_filter(){
	
	$screen = get_current_screen();
	
    if ( $screen->post_type == 'shb_tax'){
		add_filter('months_dropdown_results', '__return_empty_array');
	}
	
}

add_action('admin_head', 'shb_tax_remove_date_filter');



/* ----------------------------------------------------------------------------

   Save meta content

---------------------------------------------------------------------------- */
add_action('save_post', 'shb_tax_meta_save');
function shb_tax_meta_save( $post_id ){
	
	$prefix = 'shb';

	if ( isset($_POST['tax_meta_noncename'])) {
		
		if (!wp_verify_nonce($_POST['tax_meta_noncename'],__FILE__)) {
			return $post_id;
		}

		if ( !current_user_can( 'edit_post', $post_id ))
			return $post_id;
		
		$tax_data = get_post_meta($post_id);
		foreach($tax_data as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				if(empty($_POST[$key])) {
					delete_post_meta($post_id,$key);
				} 
		    }
		}
		
		foreach($_POST as $key => $val){
			$exp_key = explode('_', $key);
			if($exp_key[0] == $prefix){
				update_post_meta($post_id,$key,$_POST[$key]);
		    }
		}

	}

}