<?php

// Widget Class
class shb_booking_widget extends WP_Widget {


/* ----------------------------------------------------------------------------

   Widget setup

---------------------------------------------------------------------------- */

	function __construct() {
		
		parent::__construct(false, $name = esc_html__('Soho Hotel Booking Form','soho-hotel'), array(
			'description' => esc_html__('Display Booking Form','soho-hotel')
		));
	
	}


/* ----------------------------------------------------------------------------

   Display widget

---------------------------------------------------------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );
		
		$title = apply_filters('widget_title', $instance['title'] );
		$position = apply_filters('widget_position', $instance['position'] );
		
		// Get theme options
		global $sohohotel_data;

		// Set max values
		$sh_get_booking_max_rooms = 2;
		$sh_get_booking_max_guests = 3; 
		
		if(!empty(get_option('shb_booking_page'))) {
			$booking_page_url = get_permalink(get_option('shb_booking_page'));
		} else {
			$booking_page_url = '';
		}
		
		$guestclass_ids = shb_get_all_ids('shb_guestclass');
		$shb_get_booking_max_guests = 10;

		$guestclass_ids = shb_get_all_ids('shb_guestclass');
		$guestclass_count = count($guestclass_ids);

		if ($guestclass_count % 2 == 0) {
			$guestclass_cols = 'shb-guest-2-cols';
		} else {
			$guestclass_cols = 'shb-guest-1-cols';
		} ?>
		
		<?php if ($position == 'footer') {
			
			global $shb_allowed_html_array;
			echo wp_kses($before_widget,$shb_allowed_html_array);
			if ( $title ) {
				echo wp_kses($before_title . $title . $after_title,$shb_allowed_html_array);
			 }
			
		} ?>
		
		<!-- BEGIN .sidebar-booking-form -->
		<div class="sidebar-booking-form sohohotel-widget">

			<form action="<?php echo $booking_page_url; ?>" method="post">
				
				<?php $shb_datepicker_data["blocked_dates"] = shb_get_blocked_dates(get_the_ID());
				$shb_datepicker_data["season"] = shb_get_restrictions(get_the_ID());
		
				$shb_datepicker_settings = array(
					"panels" => 2,
					"inline" => false,
					"noselect" => false,
					"dateformat" => 'DD/MM/YYYY',
					"checkin" => '',
					"checkout" => ''
				);
		
				echo shbdp($shb_datepicker_data,$shb_datepicker_settings); 
	
				?>
				
				<div class="shb-clearfix">
				
				<?php foreach($guestclass_ids as $key => $val) { ?>
					
					<div class="<?php echo $guestclass_cols; ?>">
				
						<label for="shb-<?php echo $val; ?>-1"><?php echo get_the_title($val); ?></label>	
						<div class="shb-select-wrapper">
							<i class="fa fa-angle-down"></i>
							<select id="shb-<?php echo $val; ?>-1" name="shb-<?php echo $val; ?>-1">
					
								<?php foreach (range(0, $shb_get_booking_max_guests) as $r) { ?>
									<option value="<?php echo $r; ?>"><?php echo $r; ?></option>
								<?php } ?>

							</select>
						</div>
			
					</div>
				
				<?php } ?>
				
				</div>
				
				<input type="hidden" name="shb-external-form" value="1" />
				
				<button type="submit"><?php _e('Check Availability','sohohotel_booking'); ?></button>
		
			</form>
			
		<!-- END .sidebar-booking-form -->
		</div>
		
		<?php
		
		if ($position == 'footer') {
			
			echo wp_kses($after_widget,$shb_allowed_html_array);
			
		}
		
	}	
	
	
/* ----------------------------------------------------------------------------

   Update widget

---------------------------------------------------------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['position'] = strip_tags( $new_instance['position'] );
		return $instance;
	}
	
	
/* ----------------------------------------------------------------------------

   Widget input form

---------------------------------------------------------------------------- */

	function form( $instance ) {
		$defaults = array(
		'title' => 'Booking Form',
		'position' => 'sidebar'
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', 'soho-hotel'); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'position' )); ?>"><?php esc_html_e('Widget Position:', 'soho-hotel'); ?></label>
			<select id="<?php echo esc_attr($this->get_field_id( 'position' )); ?>" class="widefat" name="<?php echo esc_attr($this->get_field_name( 'position' )); ?>">
				<option value="sidebar" <?php if ( $instance['position'] == 'sidebar' ) {echo 'selected="selected"';} ?>><?php esc_html_e('Sidebar', 'soho-hotel'); ?></option>
				<option value="footer" <?php if ( $instance['position'] == 'footer' ) {echo 'selected="selected"';} ?>><?php esc_html_e('Footer', 'soho-hotel'); ?></option>
			</select>
		</p>
		
	<?php
	}	
	
}

// Add widget function to widgets_init
add_action( 'widgets_init', 'shb_booking_widget' );

// Register Widget
function shb_booking_widget() {
	register_widget( 'shb_booking_widget' );
}